import { $ } from "execa";
import gitRemoteOriginUrl from "git-remote-origin-url";
import gitUrlParse from "git-url-parse";
import lazyValue from "lazy-value";
import * as fs from "node:fs/promises";
import npmUser from "npm-user";
import { readPackageData } from "../../packages.js";
import { tryCatchAsync } from "../../tryCatchAsync.js";
import { tryCatchLazyValueAsync } from "../../tryCatchLazyValueAsync.js";
import { parsePackageAuthor } from "./parsePackageAuthor.js";
import { readDefaultsFromDevelopment } from "./readDefaultsFromDevelopment.js";
import { readDefaultsFromReadme } from "./readDefaultsFromReadme.js";
function createOptionDefaults(promptedOptions) {
  const gitDefaults = tryCatchLazyValueAsync(
    async () => gitUrlParse(await gitRemoteOriginUrl())
  );
  const npmDefaults = tryCatchLazyValueAsync(async () => {
    const whoami = (await $`npm whoami`).stdout;
    return whoami ? await npmUser(whoami) : void 0;
  });
  const packageData = lazyValue(readPackageData);
  const packageAuthor = lazyValue(
    async () => parsePackageAuthor(await packageData())
  );
  return {
    author: async () => (await packageAuthor()).author ?? npmDefaults.name,
    bin: async () => (await packageData()).bin,
    description: async () => (await packageData()).description,
    email: async () => {
      const gitEmail = await tryCatchAsync(
        async () => (await $`git config --get user.email`).stdout
      );
      const npmEmail = (await npmDefaults())?.email ?? (await packageAuthor()).email;
      return gitEmail || npmEmail ? { github: gitEmail || npmEmail, npm: npmEmail || gitEmail } : void 0;
    },
    funding: async () => await tryCatchAsync(
      async () => (await fs.readFile(".github/FUNDING.yml")).toString().split(":")[1]?.trim()
    ),
    owner: async () => (await gitDefaults())?.organization ?? (await packageAuthor()).author,
    repository: async () => promptedOptions?.repository ?? (await gitDefaults())?.name ?? (await packageData()).name,
    ...readDefaultsFromDevelopment(),
    ...readDefaultsFromReadme()
  };
}
export {
  createOptionDefaults
};
//# sourceMappingURL=index.js.map