function generateTopContent(options, existingBadges) {
  const remainingExistingBadges = new Set(existingBadges);
  const badges = [];
  for (const [badgeLine, existingMatcher] of [
    [
      !options.excludeAllContributors && `<!-- prettier-ignore-start -->
	<!-- ALL-CONTRIBUTORS-BADGE:START - Do not remove or modify this section -->
	<a href="#contributors" target="_blank"><img alt="\u{1F46A} All Contributors: 1" src="https://img.shields.io/badge/\u{1F46A}_all_contributors-1-21bb42.svg" /></a>
	<!-- ALL-CONTRIBUTORS-BADGE:END -->
	<!-- prettier-ignore-end -->`,
      /<a\s+href.*contributors.*All\s+Contributors/
    ],
    [
      `<a href="https://github.com/${options.owner}/${options.repository}/blob/main/.github/CODE_OF_CONDUCT.md" target="_blank"><img alt="\u{1F91D} Code of Conduct: Kept" src="https://img.shields.io/badge/%F0%9F%A4%9D_code_of_conduct-kept-21bb42" /></a>`,
      /CODE_OF_CONDUCT\.md/
    ],
    [
      !options.excludeTests && `<a href="https://codecov.io/gh/${options.owner}/${options.repository}" target="_blank"><img alt="\u{1F9EA} Coverage" src="https://img.shields.io/codecov/c/github/${options.owner}/${options.repository}?label=%F0%9F%A7%AA%20coverage" /></a>`,
      /https:\/\/codecov\.io\/gh/
    ],
    [
      `<a href="https://github.com/${options.owner}/${options.repository}/blob/main/LICENSE.md" target="_blank"><img alt="\u{1F4DD} License: MIT" src="https://img.shields.io/badge/%F0%9F%93%9D_license-MIT-21bb42.svg"></a>`,
      /LICENSE\.(md|txt)/
    ],
    [
      `<a href="http://npmjs.com/package/${options.repository}"><img alt="\u{1F4E6} npm version" src="https://img.shields.io/npm/v/${options.repository}?color=21bb42&label=%F0%9F%93%A6%20npm" /></a>`,
      /npm.*v/i
    ],
    [
      `<img alt="\u{1F4AA} TypeScript: Strict" src="https://img.shields.io/badge/%F0%9F%92%AA_typescript-strict-21bb42.svg" />`,
      /typescript.*strict/i
    ]
  ]) {
    const existingMatch = existingBadges.find(
      (existingLine) => existingMatcher.test(existingLine)
    );
    if (existingMatch) {
      remainingExistingBadges.delete(existingMatch);
    }
    if (badgeLine) {
      badges.push(badgeLine);
    }
  }
  return `<h1 align="center">${options.title}</h1>

<p align="center">${options.description}</p>

<p align="center">
${[...badges, ...remainingExistingBadges].map((badge) => `	${badge}`).join("\n")}
</p>${options.logo ? `

<img align="right" alt="${options.logo.alt}" src="${options.logo.src}">

` : ""}${options.mode === "migrate" ? "" : `

## Usage

\`\`\`shell
npm i ${options.repository}
\`\`\`
\`\`\`ts
import { greet } from "${options.repository}";

greet("Hello, world! \u{1F496}");
\`\`\``}`;
}
export {
  generateTopContent
};
//# sourceMappingURL=generateTopContent.js.map